@@ -109,7 +109,7 @@ class UnsupervisedTrainer:
         self.seed = seed
 
         self.train_instance_name = train_instance_name
-        if restore_epoch > 0:
+        if restore_epoch > 0 and type(self) == UnsupervisedTrainer:
             self.ckpt_dir = ckpt_dir
             self.load_ckpt(restore_epoch, self.ckpt_dir)
         elif ckpt_dir is not None:
